# GenomeQAML GUI
:camel: GUI wrapper for the OLC GenomeQAML

See __https://github.com/OLC-LOC-Bioinformatics/GenomeQAML__ for details.

## External Dependencies

- [Mash (v2.0 or greater)](https://github.com/marbl/mash)
- [Prodigal (>=2.6.2)](https://github.com/hyattpd/Prodigal)

Both of these need to be downloaded and included on your $PATH.
